@@ -3,7 +3,6 @@ use std::fmt;
 use std::sync::Arc;
 use std::time::Duration;
 use tokio::io::{stdout, AsyncWriteExt, Stdout};
-use tokio::runtime::Runtime;
 use tokio::sync::mpsc::{unbounded_channel, UnboundedSender as DropTx};
 use tokio::sync::watch::{channel as watch_channel, Receiver as WatchRx};
 use tokio::sync::Mutex;
@@ -15,7 +14,7 @@ use tokio::time::sleep;
 ///
 /// Its mutable interior is guarded by `Arc<Mutex<...>>`.
 pub struct BufSink<T: AsyncWriteExt + Unpin + Send + 'static> {
-    rt: Arc<Runtime>,
+    rt: tokio::runtime::Handle,
     interior: Arc<Mutex<Interior<T>>>,
     drop_chan_tx: DropTx<EmptySignal>,
     last_flush_err_chan_rx: WatchRx<Option<Arc<std::io::Error>>>,
@@ -203,17 +202,24 @@ impl<T: AsyncWriteExt + Unpin + Send + 'static> Interior<T> {
 pub struct SinkOptions<T: AsyncWriteExt + Unpin + Send + 'static> {
     pub buffer: Option<BufferOverflowThreshold>,
     pub flush_timeout_ms: u64,
-    pub tokio_runtime: Arc<Runtime>,
+    pub tokio_runtime: tokio::runtime::Handle,
     pub output_writer: T,
 }
 
 impl Default for SinkOptions<Stdout> {
+    /// # Panic
+    ///
+    /// Panics if called outside of a tokio runtime.
     fn default() -> Self {
-        // unwrap safety: any panic will cause default_options_dont_panic() test to fail
         Self {
+            // unwrap safety: any panic will cause default_options_dont_panic() test to fail
             buffer: Some(BufferOverflowThreshold::new(64 * 1024).unwrap()),
             flush_timeout_ms: 100,
-            tokio_runtime: Arc::new(Runtime::new().unwrap()),
+            tokio_runtime: if let Ok(handle) = tokio::runtime::Handle::try_current() {
+                handle
+            } else {
+                panic!("SinkOptions::default() called outside of a tokio runtime")
+            },
             output_writer: stdout(),
         }
     }
@@ -286,17 +292,20 @@ mod tests {
 
     #[test]
     fn default_options_dont_panic() {
-        assert_eq!(100, SinkOptions::default().flush_timeout_ms); // no is panic good enough
+        let rt = tokio::runtime::Runtime::new().unwrap();
+        rt.block_on(async {
+            assert_eq!(100, SinkOptions::default().flush_timeout_ms); // no is panic good enough
+        });
     }
 
     #[test]
     fn no_buffer() {
         // setup
-        let rt = Arc::new(Runtime::new().unwrap());
+        let rt = tokio::runtime::Runtime::new().unwrap();
         let opts = SinkOptions {
             buffer: None,
             flush_timeout_ms: 30,
-            tokio_runtime: rt.clone(),
+            tokio_runtime: rt.handle().clone(),
             output_writer: Vec::new(),
         };
         let mem_sink = Arc::new(BufSink::new(opts));
@@ -325,11 +334,11 @@ mod tests {
     #[test]
     fn timeout_flush() {
         // setup
-        let rt = Arc::new(Runtime::new().unwrap());
+        let rt = tokio::runtime::Runtime::new().unwrap();
         let opts = SinkOptions {
             buffer: Some(BufferOverflowThreshold::new(64 * 1024).unwrap()),
             flush_timeout_ms: 30,
-            tokio_runtime: rt.clone(),
+            tokio_runtime: rt.handle().clone(),
             output_writer: Vec::new(),
         };
         let mem_sink = Arc::new(BufSink::new(opts));
@@ -374,11 +383,11 @@ mod tests {
     #[test]
     fn overflow_flush() {
         // setup
-        let rt = Arc::new(Runtime::new().unwrap());
+        let rt = tokio::runtime::Runtime::new().unwrap();
         let opts = SinkOptions {
             buffer: Some(BufferOverflowThreshold::new(1 * 1024).unwrap()),
             flush_timeout_ms: 30,
-            tokio_runtime: rt.clone(),
+            tokio_runtime: rt.handle().clone(),
             output_writer: Vec::new(),
         };
         let mem_sink = Arc::new(BufSink::new(opts));
@@ -445,11 +454,11 @@ mod tests {
             }
         }
 
-        let rt = Arc::new(Runtime::new().unwrap());
+        let rt = tokio::runtime::Runtime::new().unwrap();
         let opts = SinkOptions {
             buffer: Some(BufferOverflowThreshold::new(1 * 1024).unwrap()),
             flush_timeout_ms: 20,
-            tokio_runtime: rt.clone(),
+            tokio_runtime: rt.handle().clone(),
             output_writer: ProblematicWriter,
         };
         let mem_sink = Arc::new(BufSink::new(opts));
